from distutils.core import setup

setup(
    name        = 'liutest',
    version     = '1.0.2',
    py_modules  = ['liutest'],
    author      = 'blazeliu',
    author_email= 'spiritliu@126.com',
    url         = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists.',
    )
